@@ -3,7 +3,7 @@ from langchain_qwq import ChatQwen
 from langchain_siliconflow import ChatSiliconFlow
 from dotenv import load_dotenv
 
-from langchain_dev_utils.chat_model import load_chat_model, register_model_provider
+from langchain_dev_utils import load_chat_model, register_model_provider
 import pytest
 
 load_dotenv()
@@ -21,10 +21,12 @@ def test_model_invoke():
     model3 = load_chat_model(
         "openrouter:deepseek/deepseek-chat-v3.1:free", temperature=0
     )
+    model4 = load_chat_model("deepseek:deepseek-chat")
 
     assert model1.invoke("what's your name").content
     assert model2.invoke("what's your name").content
     assert model3.invoke("what's your name").content
+    assert model4.invoke("what's your name").content
 
 
 @pytest.mark.asyncio
@@ -36,13 +38,16 @@ async def test_model_ainvoke():
     model3 = load_chat_model(
         "openrouter:deepseek/deepseek-chat-v3.1:free", temperature=0
     )
+    model4 = load_chat_model("deepseek:deepseek-chat")
 
     response1 = await model1.ainvoke("what's your name")
     response2 = await model2.ainvoke("what's your name")
     response3 = await model3.ainvoke("what's your name")
+    response4 = await model4.ainvoke("what's your name")
     assert response1.content
     assert response2.content
     assert response3.content
+    assert response4.content
 
 
 def test_model_tool_calling():
@@ -62,6 +67,7 @@ def test_model_tool_calling():
     model3 = load_chat_model(
         "openrouter:deepseek/deepseek-chat-v3.1:free", temperature=0
     ).bind_tools([get_current_time])
+    model4 = load_chat_model("deepseek:deepseek-chat").bind_tools([get_current_time])
 
     response1 = model1.invoke("what's the time")
     assert (
@@ -76,6 +82,10 @@ def test_model_tool_calling():
     assert (
         hasattr(response3, "tool_calls") and len(response3.tool_calls) == 1  # type: ignore
     )
+    response4 = model4.invoke("what's the time")
+    assert (
+        hasattr(response4, "tool_calls") and len(response4.tool_calls) == 1  # type: ignore
+    )
 
 
 @pytest.mark.asyncio
@@ -96,6 +106,7 @@ async def test_model_tool_calling_async():
     model3 = load_chat_model(
         "openrouter:deepseek/deepseek-chat-v3.1:free", temperature=0
     ).bind_tools([get_current_time])
+    model4 = load_chat_model("deepseek:deepseek-chat").bind_tools([get_current_time])
 
     response1 = await model1.ainvoke("what's the time")
     assert (
@@ -110,3 +121,7 @@ async def test_model_tool_calling_async():
     assert (
         hasattr(response3, "tool_calls") and len(response3.tool_calls) == 1  # type: ignore
     )
+    response4 = await model4.ainvoke("what's the time")
+    assert (
+        hasattr(response4, "tool_calls") and len(response4.tool_calls) == 1  # type: ignore
+    )
